==> ideaIC-211.7442.40-sources.jar: com/intellij/codeInsight/navigation/actions/TypeDeclarationProvider.java <==
/*
 * Copyright 2000-2019 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.codeInsight.navigation.actions;

import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.psi.PsiElement;
import org.jetbrains.annotations.Nls;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * @author yole
 */
public interface TypeDeclarationProvider {
  ExtensionPointName<TypeDeclarationProvider> EP_NAME = ExtensionPointName.create("com.intellij.typeDeclarationProvider");

  /**
   * Provides an array of declarations of type of given {@code symbol}.
   *
   * @param symbol input PSI element
   * @return all target declarations as an array of {@code PsiElement} or {@code null} if none were found
   */
  PsiElement @Nullable [] getSymbolTypeDeclarations(@NotNull PsiElement symbol);

  /**
   * Provides the custom action text.
   *
   * @param context the action data context.
   * @return the custom text or {@code null} to use the default text.
   */
  @Nullable
  @Nls(capitalization = Nls.Capitalization.Title)
  default String getActionText(@NotNull DataContext context) {
    return null;
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/codeInsight/navigation/actions/TypeDeclarationProvider.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.codeInsight.navigation.actions;

import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.extensions.ExtensionPointName;
import com.intellij.psi.PsiElement;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * @author yole
 */
public interface TypeDeclarationProvider {
  ExtensionPointName<TypeDeclarationProvider> EP_NAME = ExtensionPointName.create("com.intellij.typeDeclarationProvider");

  /**
   * Provides an array of declarations of type of given {@code symbol}.
   *
   * @param symbol input PSI element
   * @return all target declarations as an array of {@code PsiElement} or null if none were found
   */
  @Nullable
  PsiElement[] getSymbolTypeDeclarations(@NotNull PsiElement symbol);

  /**
   * Provides the custom action text.
   *
   * @param context the action data context
   * @return the custom text or null to use the default text
   */
  @Nullable
  default String getActionText(@NotNull DataContext context) {
    return null;
  }
}
